fn main() {
    eprintln!(
        "You have to add `sample.wav` to `soloud` directory  and modify this example to run it!!"
    );
    // use soloud::*;
    // let sl = Soloud::default().unwrap();
    // let mut wav = audio::Wav::default();
    // wav.load_mem(include_bytes!("../../sample.wav")).unwrap();
    // sl.play(&wav);
    // while sl.voice_count() > 0 {
    //     std::thread::sleep(std::time::Duration::from_millis(100));
    // }
}
